/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2013 Frederik Heber. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * toPythonString.cpp
 *
 *  Created on: Aug 26, 2013
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "toPythonString.hpp"

#include "Element/element.hpp"
#include "LinearAlgebra/RealSpaceMatrix.hpp"
#include "LinearAlgebra/Vector.hpp"

#include "Parameters/Specifics/KeyValuePair.hpp"

template <>
const std::string toPythonString( const boost::filesystem::path & _value)
{
  return _value.string();
}

template <>
const std::string toPythonString( const element & _value)
{
  std::stringstream output;
  output << _value.getAtomicNumber();
  return output.str();
}

template <>
const std::string toPythonString( const KeyValuePair & _value)
{
  std::stringstream output;
  const char semicolon(';');
  const size_t semicolon_pos = _value.find_last_of(semicolon, std::string::npos);
  const size_t final_equality_pos = _value.find('=', semicolon_pos);
  output << _value;
  if ((semicolon_pos == std::string::npos)
      || (final_equality_pos != std::string::npos))
    output << semicolon;
  return output.str();
}

template <>
const std::string toPythonString( const RealSpaceMatrix& _value)
{
  std::stringstream output;
  output
    << _value.at(0,0) << ","
    << _value.at(0,1) << ","
    << _value.at(0,2) << ","
    << _value.at(1,1) << ","
    << _value.at(1,2) << ","
    << _value.at(2,2);
  return output.str();
}

template <>
const std::string toPythonString( const Vector& _value)
{
  std::stringstream output;
  output << _value[0] << "," << _value[1] << "," << _value[2];
  return output.str();
}
