/*
 * TextDialog.hpp
 *
 *  Created on: Jan 5, 2010
 *      Author: crueger
 */

#ifndef TEXTDIALOG_HPP_
#define TEXTDIALOG_HPP_

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif


#include <string>

#include "Dialog.hpp"

class atom;
class element;
class molecule;
class KeyValuePair;
class RealSpaceMatrix;
class Vector;

class TextDialog : public Dialog
{
public:
  TextDialog(const std::string &_title);
  virtual ~TextDialog();

  virtual void queryEmpty(const std::string ="", const std::string = "");
  virtual void queryBoolean(Parameter<bool> &, const std::string ="", const std::string = "");
  virtual void queryInt(Parameter<int> &, const std::string ="", const std::string = "");
  virtual void queryInts(Parameter<std::vector<int> > &, const std::string ="", const std::string = "");
  virtual void queryUnsignedInt(Parameter<unsigned int> &, const std::string ="", const std::string = "");
  virtual void queryUnsignedInts(Parameter<std::vector<unsigned int> > &, const std::string ="", const std::string = "");
  virtual void queryString(Parameter<std::string> &, const std::string ="", const std::string = "");
  virtual void queryStrings(Parameter<std::vector<std::string> > &, const std::string ="", const std::string = "");
  virtual void queryDouble(Parameter<double> &, const std::string ="", const std::string = "");
  virtual void queryDoubles(Parameter<std::vector<double> > &, const std::string ="", const std::string = "");
  virtual void queryAtom(Parameter<const atom *> &, const std::string = "",std::string = "");
  virtual void queryAtoms(Parameter<std::vector<const atom *> > &, const std::string = "",std::string = "");
  virtual void queryMolecule(Parameter<const molecule *> &, const std::string = "",std::string = "");
  virtual void queryMolecules(Parameter<std::vector<const molecule *> > &, const std::string = "",std::string = "");
  virtual void queryVector(Parameter<Vector> &, const std::string ="", const std::string = "");
  virtual void queryVectors(Parameter<std::vector<Vector> > &, const std::string ="", const std::string = "");
  virtual void queryRealSpaceMatrix(Parameter<RealSpaceMatrix> &, const std::string ="", const std::string = "");
  virtual void queryElement(Parameter<const element *> &, const std::string ="", const std::string = "");
  virtual void queryElements(Parameter<std::vector<const element *> > &, const std::string ="", const std::string = "");
  virtual void queryFile(Parameter<boost::filesystem::path> &, const std::string ="", const std::string = "");
  virtual void queryFiles(Parameter<std::vector<boost::filesystem::path> > &, const std::string ="", const std::string = "");
  virtual void queryKeyValuePair(Parameter<KeyValuePair> &, const std::string ="", const std::string = "");
  virtual void queryKeyValuePairs(Parameter< std::vector<KeyValuePair> > &, const std::string ="", const std::string = "");

protected:
  // specialized stuff for text queries
  // all placed into Query/TextQuery.hpp
  // !please adhere to alphabetical ordering!
  class AtomTextQuery;
  class AtomsTextQuery;
  class BooleanTextQuery;
  class DoubleTextQuery;
  class DoublesTextQuery;
  class ElementTextQuery;
  class ElementsTextQuery;
  class EmptyTextQuery;
  class FileTextQuery;
  class FilesTextQuery;
  class IntTextQuery;
  class IntsTextQuery;
  class KeyValuePairTextQuery;
  class KeyValuePairsTextQuery;
  class MoleculeTextQuery;
  class MoleculesTextQuery;
  class RealSpaceMatrixTextQuery;
  class StringTextQuery;
  class StringsTextQuery;
  class UnsignedIntTextQuery;
  class UnsignedIntsTextQuery;
  class VectorTextQuery;
  class VectorsTextQuery;
};

#endif /* TEXTDIALOG_HPP_ */
